=======================
FAQ and Troubleshooting
=======================

Here are some common questions and issues. Please feel free to open an issue if it doesn't solve your problem.

---------------------------------------------
In Cesium, my tileset position is incorrect
---------------------------------------------

Cesium scene is in EPSG:4978, did you use `--srs_out 4978` in your `py3dtiles convert` invocation?
